package async_rpc_kernel

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Direct_stream_writer.ExpertSource

Sourceval write : 'a t -> buf:Core.Bigstring.t -> pos:int -> len:int -> [ `Flushed of unit Async_kernel.Deferred.t | `Closed ]
Sourceval write_without_pushback : 'a t -> buf:Core.Bigstring.t -> pos:int -> len:int -> [ `Ok | `Closed ]
Sourceval schedule_write : 'a t -> buf:Core.Bigstring.t -> pos:int -> len:int -> [ `Flushed of unit Async_kernel.Deferred.t Gel.t | `Closed ]

Similar to write_without_pushback but you may not modify the written portion of the bigstring until either:

  • schedule_write returns `Closed (indicating the connection is closed or the client aborted the rpc)
  • The returned deferred in the `Flushed case becomes determined