package async_rpc_kernel

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Group.BufferSource

A group internally holds a buffer to serialize messages only once. This buffer will grow automatically to accomodate bigger messages.

It is safe to share the same buffer between multiple groups.

Sourcetype t
Sourceval create : ?initial_size:int -> unit -> t