package async_rpc_kernel

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Group.ExpertSource

When these functions are used with a group created with ~send_last_value_on_add:true, the group will save a copy of the relevant part of the buffer in order to send it to writers added in the future.

Sourceval write : 'a t -> buf:Core.Bigstring.t -> pos:int -> len:int -> unit Async_kernel.Deferred.t
Sourceval write_without_pushback : 'a t -> buf:Core.Bigstring.t -> pos:int -> len:int -> unit