package async_rpc_kernel

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Async_rpc_kernel.Rpc_metadataSource

Metadata is arbitrary information provided by a caller along with the query. It is opaque to the Async RPC protocol, and may not be present on all queries. Metadata should generally be small, middleware-provided data that does not affect the callee's behavior (e.g. tracing ids). It may be subject to truncation if values provided are too large. See Connection.create for more info.

Sourcetype t = string
Sourceval sexp_of_t : t -> Sexplib0.Sexp.t
Sourceval get : unit -> t option

Retrieves the metadata in the context of the current RPC call, if it is available.